# (C) Copyright IBM Corp. 2020.

args = [
        {
            "userId": "d29d4350-5b18-45c8-a731-152ebe9fde14",
            "argumentText": "Cannabis is safer than cigarettes and alcohol, which are already legal.",
            "argumentId": "5688c70f-919a-4e1e-8eb9-3977d6fb4a55",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995426
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "Cannabis is the best substance that can help people relax.",
            "argumentId": "eb674e55-e5e5-4065-b321-057ac31e83a9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99960625
        },
        {
            "userId": "8eaa1842-7934-4e6c-986c-e8518eb658d1",
            "argumentText": "Cannabis is the best thing I did in my life, you should try too",
            "argumentId": "a538b8ab-6dff-4109-a109-4591a0effc62",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995259
        },
        {
            "userId": "d9916595-03a3-4171-8ddc-b8fa6ce4d2b8",
            "argumentText": "Cannabis is used by many people and in the current state of afraid all users are considered criminals. Cannabis should be legalized to save police resources from hunting non harmful users.",
            "argumentId": "83bbc0be-45ce-465f-9656-7a81e072a282",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995378
        },
        {
            "userId": "d9916595-03a3-4171-8ddc-b8fa6ce4d2b8",
            "argumentText": "Cannabis is used by many people for personal use in a non-harmful way. There'\''s no reason to prevent this.",
            "argumentId": "eef96999-3b82-4e52-8302-4dbdf022329c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99895585
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "Cannabis is very beneficial for people with sleeping disorder.",
            "argumentId": "65f2fe0f-248a-4e44-b5e8-abf95d658542",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99957955
        },
        {
            "userId": "b975cd84-bf0c-4a41-88ab-8e98c3139525",
            "argumentText": "Cannabis is, in fact, harmless. It'\''s an innocent fun activity, safe to use and nearly not at all addictive.",
            "argumentId": "28baa807-270f-40f4-aa58-a87ff936e97c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99842024
        },
        {
            "userId": "39d74f29-7dd1-4c41-84b3-dd4946688811",
            "argumentText": "Cannabis isn'\''t harmful, and therefore it shouldn'\''t be illegal for people to sell amd purchase it.",
            "argumentId": "345ac974-5f20-4948-9d64-dd69ad3c4aa3",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9992043
        },
        {
            "userId": "129abe46-7378-4f61-875e-0881233d20d4",
            "argumentText": "Cannabis legalization will boost the economy and will allow control the quality and the source of it.\nOther than that it will open the door for broad research in the field in large scale.",
            "argumentId": "9b2e6c90-f920-4fe5-8b1d-ed07f684981e",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9991292
        },
        {
            "userId": "dc816a39-39b8-4e30-90a6-85c6a56d5eff",
            "argumentText": "Cannabis legalization will help tresses people and improve people health and increase life quality. ",
            "argumentId": "625f096e-4125-40f4-b73f-9669c4b4bba1",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994527
        },
        {
            "userId": "67a18bdd-456d-4e84-bfb1-a1a3f448cff6",
            "argumentText": "Cannabis legalization will increase tax revenue. That tax money can be used to fix roads, fund public projects, improve schools and so on.",
            "argumentId": "f617a988-cde1-4264-a53c-f35d37e72317",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99947774
        },
        {
            "userId": "da130fba-772c-4330-a5dd-afe5cf21b5a3",
            "argumentText": "Cannabis legalization will produce plenty of revenue that can be used for anything ",
            "argumentId": "3d0fadd1-ecd2-4b1b-a7f3-31c9bf5fc1da",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9911549
        },
        {
            "userId": "436ca78d-d494-4416-a083-7f743858a941",
            "argumentText": "Cannabis legalizing will increase dependency on substances and prevent young people from investing time in revolting against wrongdoing, developing new technology and making the world a better place.",
            "argumentId": "b05cd089-1ab1-4003-867a-c47aa1bd1f98",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.95225334
        },
        {
            "userId": "18251b3e-da9e-4105-b076-a741d7d2fc3f",
            "argumentText": "Cannabis makes life better for some sick people",
            "argumentId": "ecc3e899-f585-44bc-96e6-881ab8aab518",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99950755
        },
        {
            "userId": "efcc1875-be56-4554-adcd-1b2970cf5c69",
            "argumentText": "Cannabis makes people relax which is often substitute for painkillers, which are significantly more harmful.",
            "argumentId": "f837e134-329f-4b01-a651-81a27c25df14",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.814695
        },
        {
            "userId": "c215c081-3c68-47b4-a7ae-ba64987085f0",
            "argumentText": "Cannabis makes you a fun person and so people around you can enjoy you more",
            "argumentId": "b3d131b3-3e05-4406-9e0f-f331d0cee0af",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99938893
        },
        {
            "userId": "c215c081-3c68-47b4-a7ae-ba64987085f0",
            "argumentText": "Cannabis makes you think clearer and it makes you more creative",
            "argumentId": "edfc5d50-ab1d-4143-9416-f68e3b0c60d9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9993961
        },
        {
            "userId": "014906bb-0ebc-4660-93b2-f703f4fb4410",
            "argumentText": "Cannabis may be a healthier way to relax than alcohol ",
            "argumentId": "adf1f624-25c4-4794-9738-65a11087c520",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995667
        },
        {
            "userId": "cbf92843-2409-43e9-9bfa-da3479a1157b",
            "argumentText": "Cannabis must be legalised as it mitigates a lot of hard medical diseases where conventional medicine fails.",
            "argumentId": "27df2113-1324-438b-904b-38f45d03adff",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99961865
        },
        {
            "userId": "6f075485-d93c-4057-8caa-992cb9e7fdfa",
            "argumentText": "Cannabis must be legalized because if it doesn'\''t then it will create an even more black market ",
            "argumentId": "441712c2-7e0f-4b48-92a7-d5a3d01714c8",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9988537
        },
        {
            "userId": "faa5ceb2-7e8b-4b3c-bb71-a9258b59e7d9",
            "argumentText": "Cannabis needs to be legal since table is crucial for many people. The concern that if you would allow to use cannabis it might enlarge the table crime is not realistic. cannabis is a fun table.",
            "argumentId": "41142d94-84c6-49e0-92d4-d411cb6d0ddb",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99931026
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "Cannabis oil can benefits people with seizures and cancer patients.\n",
            "argumentId": "b7e5776f-d9d4-4991-8ef7-a449da9841fa",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9990456
        },
        {
            "userId": "0f77f108-9962-4685-b7af-d075774913ad",
            "argumentText": "Cannabis reduce pain on sick patients, but not evey people Who'\''s in pain get a prescription from his doctor.",
            "argumentId": "2c065736-98c2-49b1-9085-a2be1b34db6e",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.981742
        },
        {
            "userId": "421fdd74-8d79-415c-83db-aaa6fbe6fe28",
            "argumentText": "Cannabis reduces pain for a lot of hurt people and make suffering dissapear. It has allso negative influance of short time memory so it needed to be regulate",
            "argumentId": "4134ab1f-6d10-4c35-bafa-3073343f8fa9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9704461
        },
        {
            "userId": "4a9c371c-4408-4946-bc27-e90df235dd46",
            "argumentText": "Cannabis research show certain cannabanoids help with PTSD, cancer and Parkinson patients.\nCannabis is less addictive than many other controlled and uncontrolled substances such as alcohol, sugar and caffeine ",
            "argumentId": "b57d7e2b-ef8b-483d-a21c-3db06bc640cb",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994081
        },
        {
            "userId": "2799164b-1ec1-4f50-afaa-2d405d14bf7f",
            "argumentText": "Cannabis shoud be legalized because it can help many people who are in pain",
            "argumentId": "93e6c27d-86ac-49d8-a913-26d00f33dbe5",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995018
        },
        {
            "userId": "a7f66f69-fe98-4f28-a02d-2a6bbd825e84",
            "argumentText": "Cannabis shoukd be elegurise to help people that have big pains. ",
            "argumentId": "693583c7-8655-4361-a6bb-562af6989494",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99910796
        },
        {
            "userId": "4d7f56a5-9a4d-4af6-910a-e93c2153151b",
            "argumentText": "Cannabis shoul be legalized because it can improve people health.",
            "argumentId": "b26bff9c-121a-499b-a7c7-de32144005ca",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995841
        },
        {
            "userId": "bac58490-46e5-4fc7-9c10-9a124a78e914",
            "argumentText": "Cannabis should be allowed because cannabis smokers are so funny ",
            "argumentId": "9dc091f6-616a-4fec-be64-d1668b795e08",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99957645
        },
        {
            "userId": "1ae1b0e6-9a14-4326-9120-f4344bcab744",
            "argumentText": "Cannabis should be allowed for boosting creativity and fun in life",
            "argumentId": "5904a249-212d-44e2-a27c-95a80e0c485c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995738
        },
        {
            "userId": "056ebbe1-1662-412a-9e5d-e3b508987516",
            "argumentText": "Cannabis should be allowed to make Moshe Feiglin leave us alone.",
            "argumentId": "2d66062b-9715-45e6-b0fe-b2aa1de24fed",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9993298
        },
        {
            "userId": "b2b0ce8c-6a4f-4b07-965f-75d9c8aab762",
            "argumentText": "Cannabis should be legal as it'\''s green and natural, so it contributes to a green environment",
            "argumentId": "ae87f700-68ce-4fa9-b45a-3e0b4189b5ef",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995705
        },
        {
            "userId": "45979188-7f04-41dc-8d4b-d5787ce89cde",
            "argumentText": "Cannabis should be legal as long as alcohol is legal because it has a similar effect.",
            "argumentId": "8bda6017-748d-4f67-8322-2944cb25dc50",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994806
        },
        {
            "userId": "49a880f5-9d9a-4e6b-9b84-cee2419d75cf",
            "argumentText": "Cannabis should be legal as to give people the opportunity to choose. People know what right for them. ",
            "argumentId": "b9f45eb7-97ec-47de-af2a-fa74b41386f7",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99951255
        },
        {
            "userId": "bac58490-46e5-4fc7-9c10-9a124a78e914",
            "argumentText": "Cannabis should be legal because cannabis smokers are less violent than most people ",
            "argumentId": "dbdadf6d-91d1-4ce6-bcae-f742dec51ac4",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996022
        },
        {
            "userId": "1ada2b59-b0c0-46b2-8bfa-c84f110cfc95",
            "argumentText": "Cannabis should be legal because finnaly it would be as happened with alcohol, tabak, etc",
            "argumentId": "417d0443-4f27-490e-8be7-7576ccfaf9a3",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995469
        },
        {
            "userId": "51d0602e-dd48-4f9e-b67e-5ea164f9bf0c",
            "argumentText": "Cannabis should be legal because it help people who sick and need to support them. ",
            "argumentId": "0ab47f7e-2f87-423a-8a34-6e8acd29cd10",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99959314
        },
        {
            "userId": "15228bdc-b92e-4725-82ae-4af09554884a",
            "argumentText": "Cannabis should be legal because it would make you see blue and pink dancing elephants. ",
            "argumentId": "a2f9da5d-8943-4278-9e6f-46ab3e4ebb5e",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99919236
        },
        {
            "userId": "ef22606d-c7e1-4cd1-9b18-4f89e6506da9",
            "argumentText": "Cannabis should be legalised because it causes no physical dependency in the drug.",
            "argumentId": "cbc21d1d-3eaf-4fe7-b568-d926f083b867",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99961936
        },
        {
            "userId": "60212907-2140-4bbc-b1b2-088e6a56ee37",
            "argumentText": "Cannabis should be legalised because it is a basic human right",
            "argumentId": "c54ac837-761d-4918-a9e9-518ede68a397",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995941
        },
        {
            "userId": "ef22606d-c7e1-4cd1-9b18-4f89e6506da9",
            "argumentText": "Cannabis should be legalised because its affects on humans causes reduction in road accidents.",
            "argumentId": "2d7a37cd-99b8-4a51-ac17-308bfb1d8f5f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996005
        },
        {
            "userId": "058014d0-8af9-4254-83fe-440c684376ad",
            "argumentText": "Cannabis should be legalize because  many people use it already, which are good citizens, and we should not make them criminials.",
            "argumentId": "edb0dde1-cdb9-465a-a3bd-e993ea8b7b7d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999117
        },
        {
            "userId": "f6e903a3-763c-466c-a411-e55362b54a12",
            "argumentText": "Cannabis should be legalize because it improve our orgasms",
            "argumentId": "91a0de75-af83-4d71-9282-b03573f0b3e3",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995407
        },
        {
            "userId": "f6e903a3-763c-466c-a411-e55362b54a12",
            "argumentText": "Cannabis should be legalize because it makes people horny. ",
            "argumentId": "2678e2aa-3f8c-47a1-8855-291f410994fa",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99874103
        },
        {
            "userId": "15228bdc-b92e-4725-82ae-4af09554884a",
            "argumentText": "Cannabis should be legalized , but there should be age restriction put in place and limitation on the amounts approved for personal usage.",
            "argumentId": "2752b6ad-6c3d-4e3d-8e2e-fe66fdc91049",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999138
        },
        {
            "userId": "cc440d74-d636-4edb-8526-bfa204c06c2d",
            "argumentText": "Cannabis should be legalized as a drug because it has therapeutic qualities. should also be supervised as a drug",
            "argumentId": "06627509-6ede-4060-8742-7b946e154eac",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99917495
        },
        {
            "userId": "191557fc-58c0-4d2a-8e34-59c08b7dac88",
            "argumentText": "Cannabis should be legalized as it can assist in many medical condition without any side affects or dependency. ",
            "argumentId": "f9a9649a-89cf-47aa-bf42-ae8c90b9c0a3",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996153
        },
        {
            "userId": "191557fc-58c0-4d2a-8e34-59c08b7dac88",
            "argumentText": "Cannabis should be legalized as it can be controlled easy with the distribution to the needed clients for medical needs",
            "argumentId": "9aae3e1e-f981-4e90-93f4-ec9485d9fd72",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995972
        },
        {
            "userId": "191557fc-58c0-4d2a-8e34-59c08b7dac88",
            "argumentText": "Cannabis should be legalized as it can be controlled easy with the distribution to the needed clients for medical needsw",
            "argumentId": "579b56a9-577f-4556-9013-d0393012b81c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99958956
        },
        {
            "userId": "191557fc-58c0-4d2a-8e34-59c08b7dac88",
            "argumentText": "Cannabis should be legalized as it is a natural medicine. No cimicals added.",
            "argumentId": "a530bf2b-987c-4543-a202-30e1b3fc0864",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995116
        },
        {
            "userId": "6f075485-d93c-4057-8caa-992cb9e7fdfa",
            "argumentText": "Cannabis should be legalized as it is already legalized in many advanced countries that found it more beneficial than damaging ",
            "argumentId": "6e54fe2a-1dc4-4415-aec9-a2afbf0eb90d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99960387
        },
        {
            "userId": "6d1caaa1-2a82-4723-b136-e494197d9e39",
            "argumentText": "Cannabis should be legalized as it is used anyway\nAnd the state could have large profits from sales\nTaxes.",
            "argumentId": "60806f49-7d60-4363-baa0-78b25c129e1a",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99932694
        },
        {
            "userId": "2e542c7c-fc79-4f5e-a54a-eb5cde61f7a7",
            "argumentText": "Cannabis should be legalized as it should be left for people to weigh pros/cons  for themselves w/o government needless intervention ",
            "argumentId": "240dbb2e-2bad-4f40-8661-fe17c2090d6d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995626
        },
        {
            "userId": "0cfed6be-f710-44af-b24a-d79e79715d1b",
            "argumentText": "Cannabis should be legalized as it will help to bring pain relief to many people who can'\''t get it today",
            "argumentId": "5d4e9946-ebea-4e3e-89b6-800a891af755",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99960124
        },
        {
            "userId": "191557fc-58c0-4d2a-8e34-59c08b7dac88",
            "argumentText": "Cannabis should be legalized as it'\''s a wonderful economic engen that can benefit Israel internal economic and not only foren countries",
            "argumentId": "086014e4-4eea-4b29-8585-a8587fd58c91",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996115
        },
        {
            "userId": "191557fc-58c0-4d2a-8e34-59c08b7dac88",
            "argumentText": "Cannabis should be legalized as it'\''s a wonderful medicine and a great economical engen",
            "argumentId": "7f542f84-2ac3-4d74-98be-e9b7c2be5851",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99961936
        },
        {
            "userId": "4209988d-4811-499a-b78a-6de2cd1722a0",
            "argumentText": "Cannabis should be legalized because  it'\''s Constitutes  a theraputic option for palative care and is able to ease the suffering of patients with many diseases. Therefore, improving the life quality of many.\n",
            "argumentId": "b6776c85-050a-4124-95fc-73c41e8aa210",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996282
        },
        {
            "userId": "fb2bca6a-21dd-447b-b660-bb67ee438cd2",
            "argumentText": "Cannabis should be legalized because Cababiss is good for the healt \n",
            "argumentId": "26aa53f5-52d5-4a29-903b-1a82eb3da609",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99959576
        },
        {
            "userId": "9f6d3588-4475-4e8e-99cb-44f4b36fd85d",
            "argumentText": "Cannabis should be legalized because The ban on it causes a significant increase in the number of crimes.",
            "argumentId": "fc1abbc9-bf3f-42bc-89a8-10c252195618",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994718
        },
        {
            "userId": "9f6d3588-4475-4e8e-99cb-44f4b36fd85d",
            "argumentText": "Cannabis should be legalized because The ban on it lowers their quality",
            "argumentId": "5238505d-ed31-46a5-9c80-b71b3fe42369",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9993937
        },
        {
            "userId": "9f6d3588-4475-4e8e-99cb-44f4b36fd85d",
            "argumentText": "Cannabis should be legalized because dozens of western countries found it better ",
            "argumentId": "cf569de9-166f-45fc-8e29-7d32173f92cf",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995965
        },
        {
            "userId": "4209988d-4811-499a-b78a-6de2cd1722a0",
            "argumentText": "Cannabis should be legalized because it can ease the suffering of patients with psychiatric disorders and  people who are copig with PTSD -due to its effects .",
            "argumentId": "7d1d1753-3f6e-4d1e-ae94-be5bd6db2539",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996115
        },
        {
            "userId": "d9916595-03a3-4171-8ddc-b8fa6ce4d2b8",
            "argumentText": "Cannabis should be legalized because it is helpful for many mentally and physically ill people.",
            "argumentId": "aec7720d-b43c-4777-9b3e-fefd77c5705c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99961483
        },
        {
            "userId": "af76b4af-26f9-4eec-9982-2faae7ea748c",
            "argumentText": "Cannabis should be legalized because it is helping people'\''s health and quality of life. People are already using it, and legalizing it will lower crime, violence and the number of people moving to more dangerous drugs",
            "argumentId": "40b47fe4-a04d-4224-99c3-5d0271dda907",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99958575
        },
        {
            "userId": "27328125-8b92-45ff-ac41-4cabb4fae063",
            "argumentText": "Cannabis should be legalized because it is much better than smokes and alcohol",
            "argumentId": "4e012ed0-b6bd-4737-a99f-b323be71b3a0",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996079
        },
        {
            "userId": "9b771cf1-0cd7-457f-9c2f-73f2a023f843",
            "argumentText": "Cannabis should be legalized because it is not addictive and by doing so there will be no more mafias selling it. ",
            "argumentId": "9ef6a0cc-52ac-4014-8172-8a790ef6bba6",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995638
        },
        {
            "userId": "014906bb-0ebc-4660-93b2-f703f4fb4410",
            "argumentText": "Cannabis should be legalized because it might be a way to help people with diseases traditional pharma hasn'\''t been able to help.",
            "argumentId": "a6ae0ded-4a63-4729-8d64-65bdf7e664b3",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996003
        },
        {
            "userId": "369a0cef-d734-4b20-8579-91eb9a45cd7d",
            "argumentText": "Cannabis should be legalized because it saves lives.",
            "argumentId": "36c68cc7-390a-4494-9867-f5571c8df4c9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996098
        },
        {
            "userId": "3954aa25-ea5e-43f1-bc5b-cce2b12335d6",
            "argumentText": "Cannabis should be legalized because it supplies a natural tension release, good feeling and above all it is harmless unlike alcohol and cigarettes.",
            "argumentId": "410dca7a-fcaa-4107-ad9f-727566498209",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999627
        },
        {
            "userId": "e6a7fa20-e032-4d50-80ab-3ef9339e0015",
            "argumentText": "Cannabis should be legalized because it touches on core freedom - sovereignty over self. People must have the freedom to decide for themselves how to use, or abuse, themselves.",
            "argumentId": "32b20fb4-fb96-4aae-b74f-9bf0045f1c1b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99955523
        },
        {
            "userId": "721a5ea9-ab8c-4b91-a4b7-9c8a20d48af7",
            "argumentText": "Cannabis should be legalized because it will reduce criminals ",
            "argumentId": "4f029f06-afdf-4914-ad25-224087ab0b31",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996108
        },
        {
            "userId": "7c0c4c51-d739-4555-88a1-2a58eae5c6a3",
            "argumentText": "Cannabis should be legalized because it will reduce suffering and pain from many people all over the world.",
            "argumentId": "7bf0c6d0-bc46-42fd-a41e-0968d89cc087",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99960506
        },
        {
            "userId": "6cb684de-a095-47d4-bd07-8d009c2d85c2",
            "argumentText": "Cannabis should be legalized because it would stop the illegal activity around it and would offer an entire economic boost",
            "argumentId": "5c2fb393-a07d-44a2-a990-88f0eb12ac3d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996122
        },
        {
            "userId": "6dd2186c-71d4-4c76-8902-8d794d8f4bbd",
            "argumentText": "Cannabis should be legalized because it'\''s not a dangerous drug and there is no scientific research to support this idea.",
            "argumentId": "1a8ef300-1ad2-4c92-81fa-4604e9f6b2a1",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994656
        },
        {
            "userId": "9f6d3588-4475-4e8e-99cb-44f4b36fd85d",
            "argumentText": "Cannabis should be legalized because it'\''s the people right to choose wether it'\''s right for them or not (after it'\''s found as not dangerous).",
            "argumentId": "11cb6737-4714-4c36-87a2-3897e7be792d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994482
        },
        {
            "userId": "82b09655-c0d9-4756-b6d5-7e196e65de1b",
            "argumentText": "Cannabis should be legalized because its make people relaxed and kindly  ",
            "argumentId": "372e5ebd-45e1-4c49-89e0-fec24ecbcfc6",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995676
        },
        {
            "userId": "d9916595-03a3-4171-8ddc-b8fa6ce4d2b8",
            "argumentText": "Cannabis should be legalized because otherwise a black market will be created, and this could be more harmful to the community than the actual use of the drug.",
            "argumentId": "9afe219e-9b43-47cd-bd57-ee84a3720679",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99932885
        },
        {
            "userId": "bbb020d9-aa35-4b5d-ad5a-4768def16157",
            "argumentText": "Cannabis should be legalized because so many people use it, and forbidding it would not help. It is legal in Holland, and it is OK",
            "argumentId": "3f2324e4-f4a2-4363-9287-1b93ea1f047f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9990854
        },
        {
            "userId": "e53607c5-4e27-4c4b-abf1-7d450b4d2b66",
            "argumentText": "Cannabis should be legalized because table should be allowed to table. If table is bot going to be table we wont see table for a few years.",
            "argumentId": "fc25bd47-4af5-4367-83be-c16195c101be",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996239
        },
        {
            "userId": "8dd1de49-43ac-485d-8df1-8dbd41734d12",
            "argumentText": "Cannabis should be legalized because that way everyone would be happy and not aware to the struggle of reality ",
            "argumentId": "b07c42de-a1a8-4f01-9eff-f6803e114ae0",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995905
        },
        {
            "userId": "ed8c36c3-b846-4316-97cf-b5c48717aeb2",
            "argumentText": "Cannabis should be legalized because thats the only way prices will go down",
            "argumentId": "e320960c-6478-433b-941b-de3e6f73e052",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999622
        },
        {
            "userId": "9f6d3588-4475-4e8e-99cb-44f4b36fd85d",
            "argumentText": "Cannabis should be legalized because the ban of it causes undesirable behavior among drug users",
            "argumentId": "e5b0748e-79c0-46bb-8cab-d43ec387cf44",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9990927
        },
        {
            "userId": "bbb020d9-aa35-4b5d-ad5a-4768def16157",
            "argumentText": "Cannabis should be legalized by producing different drugs that that different illnesses. Cannabis contains many very useful materials.",
            "argumentId": "a6236284-274b-48c4-9f3e-b99a5e6961ad",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99942815
        },
        {
            "userId": "be8f8a20-d44b-46b4-b85b-4a23988e99cd",
            "argumentText": "Cannabis should be legalized in parallel to making cigarettes illegal.",
            "argumentId": "aabaf7a2-9b76-4ef1-8b34-38135fba03a5",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9993026
        },
        {
            "userId": "fc14964f-78dd-4c35-8802-73062a1ebc34",
            "argumentText": "Cannabis should be legalized mainly due to the fact that it is critical for some medical treatments and to support people to manage regular life during heavy medical treatments ",
            "argumentId": "3f51c15d-cb7f-45b9-b346-b1c24d92a981",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9990661
        },
        {
            "userId": "93448b1d-ffbf-4c45-a9ed-6cee59f3f634",
            "argumentText": "Cannabis should be legalized only for proved medical use. ",
            "argumentId": "cfbd6d10-c734-4ec4-9869-295da02a3974",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9614507
        },
        {
            "userId": "bfef57ed-d636-4525-8307-27583228378f",
            "argumentText": "Cannabis should be legalized so its use can be controlled and organized",
            "argumentId": "42e7c8d9-d44c-4c59-a25f-35da56dfb78a",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99957454
        },
        {
            "userId": "d5ad885d-2900-4901-a9b5-d384bd6f618b",
            "argumentText": "Cannabis should be legalized so people can be calm enough and practical to legalize cannabis",
            "argumentId": "c77e628c-050d-4d11-bef5-8147deed04dc",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995576
        },
        {
            "userId": "d5ad885d-2900-4901-a9b5-d384bd6f618b",
            "argumentText": "Cannabis should be legalized so the speaker can move on to the next subject",
            "argumentId": "873ba976-c3d1-4cce-af91-daa6431ce833",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995979
        },
        {
            "userId": "d5ad885d-2900-4901-a9b5-d384bd6f618b",
            "argumentText": "Cannabis should be legalized so we can finally really really moved to the cloud ",
            "argumentId": "84b87031-2cd1-49c2-a9df-55cf1e18922a",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999524
        },
        {
            "userId": "ed8c36c3-b846-4316-97cf-b5c48717aeb2",
            "argumentText": "Cannabis should be legalized to help people'\''s health",
            "argumentId": "31193e8a-c70e-4c88-a06f-f910ec667faa",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995879
        },
        {
            "userId": "23951fac-7795-4bbe-92e5-8ae3c8b4e2ae",
            "argumentText": "Cannabis should be legalized, as it helps people be more focused.",
            "argumentId": "778cf1e6-4a3d-4921-8e75-819d352e8102",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99961555
        },
        {
            "userId": "96973630-9fd4-4998-885d-958f4b9c596e",
            "argumentText": "Cannabis should be legalized, because it has many therapeutic properties and can relieve pain.",
            "argumentId": "f838efb3-0527-4331-9987-46576b21556c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996244
        },
        {
            "userId": "29d8ea51-4805-4aaf-818c-c819fa3845f9",
            "argumentText": "Cannabis should be legalized, because it hasn'\''t been scientifically proven yet that it cause more harm to ones health than alcohol or cigarettes",
            "argumentId": "0b565b1e-d637-4bfe-a069-c66327c91617",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995636
        },
        {
            "userId": "eacfe59d-ecd7-468b-8b47-e1e2e0910274",
            "argumentText": "Cannabis should be legalized, because it'\''s less harmful then a lot of substances that are legal today.",
            "argumentId": "dde0d993-4abe-439e-bd9b-b0a68237b37b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99960387
        },
        {
            "userId": "d5f0f33a-7edf-4d3a-ad5c-374783803524",
            "argumentText": "Cannabis should be legalized, it'\''s help more then harm, if cannabis will be legalized it will hurt the Pharmaceutical companies witch is not bad thing! With cannabis we can Relieve serious diseases and save lives! ",
            "argumentId": "3eef83ef-9c2d-44cd-a325-afd82328ff4d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994594
        },
        {
            "userId": "cb6c4860-6891-40ca-9949-c0e28d5a8aff",
            "argumentText": "Cannabis should be legalized, taxed and monitored by the goverment.",
            "argumentId": "bad0ad4c-cb30-4011-8679-7db668823ebf",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999027
        },
        {
            "userId": "f4de44c9-3964-4464-a86e-842b40bb7f4e",
            "argumentText": "Cannabis should be legalized.  It is safer than alcohol. It has medical benefits. It is good for people'\''s calmness  and happiness. ",
            "argumentId": "37446999-2b59-4b71-85e8-c8efc7bc7f8f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996182
        },
        {
            "userId": "d0e4f982-404d-4618-b033-8540e517336e",
            "argumentText": "Cannabis should be legitimized because no chance to stop it\n  ",
            "argumentId": "7026ece9-1c16-42f9-b22d-e6496a52e9f5",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9974084
        },
        {
            "userId": "bac58490-46e5-4fc7-9c10-9a124a78e914",
            "argumentText": "Cannabis should be unligal because cannabis is mental disorder catalizator for some people ",
            "argumentId": "8d68c821-465b-4511-80bd-d204e4b6efe7",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.979571
        },
        {
            "userId": "384df510-46cc-4988-9bdb-08d3b8bcf336",
            "argumentText": "Cannabis should not be sold without prescription because it has been documented to cause anxiety and panic attacks in people and even trigger schizophrenia in young users, even at first use.",
            "argumentId": "59019ca0-657b-496d-a8f4-6aa7f8bc8c57",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.97498715
        },
        {
            "userId": "b975cd84-bf0c-4a41-88ab-8e98c3139525",
            "argumentText": "Cannabis use is a victimless crimes. We put inoccent juveniles in jail where they learn to become actual criminals.",
            "argumentId": "946915e0-9699-4fc6-a106-379afce36589",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99166524
        },
        {
            "userId": "5ded95bd-6a63-4d59-ab7b-839c6fdb6191",
            "argumentText": "Cannabis use is important for the religious practices for some groups. This includes Rastafarians, who are marginalized in most societies.",
            "argumentId": "e47d246f-5d04-4df5-b416-a041cb1dea37",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9993007
        },
        {
            "userId": "cbf92843-2409-43e9-9bfa-da3479a1157b",
            "argumentText": "Cannabis use is much less dangerous than alcohol, which is legal in most parts of the world.",
            "argumentId": "51945c0e-84ce-4c3b-8008-ac5f10586aef",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99945986
        },
        {
            "userId": "ac3d2751-8c5d-43b3-85c4-f44347ef49ca",
            "argumentText": "Cannabis use is much less dangerous than alcohol, which is legal in most parts of the world. People have a right to do what they want to their own bodies.",
            "argumentId": "6148e6e5-47e4-47f2-92eb-dece2c68a9d4",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995042
        },
        {
            "userId": "f2c362ba-de58-45d9-ae55-46fe3cffac65",
            "argumentText": "Cannabis use is not nearly as harmful as alcohol or tobacco and thus there is no justification to treat it as a criminal activity.",
            "argumentId": "d3daa924-1fcb-4edb-9d69-9f67086c9ac4",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9970223
        },
        {
            "userId": "b975cd84-bf0c-4a41-88ab-8e98c3139525",
            "argumentText": "Cannabis use is relatively harmless but easy to find. It diverts police resources from stopping more harmful crimes.",
            "argumentId": "a0368d06-ad7d-4446-9842-d14b09194d4d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.76538575
        },
        {
            "userId": "8e627a83-47f2-42ec-aedd-7d7397a710d3",
            "argumentText": "Cannabis will no longer be a gateway drug once it is legalized and hard drugs are left banned.",
            "argumentId": "0ac6f385-c428-4587-88b0-c5a37322d237",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9976189
        },
        {
            "userId": "94dc9b32-ccd8-43cb-9e13-d5b79ea897bc",
            "argumentText": "Cannabis will recover many people from diseases without using surgeries",
            "argumentId": "6d4d446e-ccb9-42c6-a55b-f75e24c4a077",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9987391
        },
        {
            "userId": "0f77f108-9962-4685-b7af-d075774913ad",
            "argumentText": "Cannabis'\''s lis ess adaptive and less dangerous than cigaretts tand alcohol together. ",
            "argumentId": "bc95fe6b-5629-472a-8f46-8636fa5b9738",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9992645
        },
        {
            "userId": "e0091e8b-044e-403d-99e9-62ad1fdb1afc",
            "argumentText": "Cannabis,  as all other substances,  should be legalized,  since its consumption doesn'\''t hurt any other person ",
            "argumentId": "218bbcd7-b7a7-4b63-b379-e39048f1ae51",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999606
        },
        {
            "userId": "d29d4350-5b18-45c8-a731-152ebe9fde14",
            "argumentText": "Changing minimum sentencing laws and enacting decriminalization are good enough policy alternatives to solve the most severe problems, without any of the negative effects of full legalization of cannabis. ",
            "argumentId": "7a85ba54-b39b-4ea4-9a07-ab69f605b26f",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.9917555
        },
        {
            "userId": "f3ae12b2-e9c6-45ab-b33f-5e05dbca46f4",
            "argumentText": "Citizens are not clever enough to decide what is good for them  You need a computer to make the decisions for them, ask Watson.",
            "argumentId": "03d9e770-00a8-4089-babf-2c68979521d5",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.86761963
        },
        {
            "userId": "5eae8630-322a-48c3-bdff-ba41ca81848c",
            "argumentText": "Concentrating on been relaxed is better than focussing on Aggressions .",
            "argumentId": "df5c1c06-6931-4c16-ac94-244b9dccf46f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.15239656
        },
        {
            "userId": "32eba00e-81ee-4331-a772-04dbd93e34c8",
            "argumentText": "Crime and violence are greatly increased due to illegal selling and buying of cannabis. Legalization would logically end the need for such criminal behavior.",
            "argumentId": "fba18dc1-2c47-48e4-a788-f406ad5f232b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99875057
        },
        {
            "userId": "b975cd84-bf0c-4a41-88ab-8e98c3139525",
            "argumentText": "Criminalization of cannabis has led to a black market revolving around it. Better as well legalize it so we can regulate it and keep people away from criminal activity.",
            "argumentId": "d9fdf16b-4b0e-4747-b688-2a396e22bc00",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9991385
        },
        {
            "userId": "ca1f1de3-bc1a-4866-b451-81123b8b140c",
            "argumentText": "Daniel Malka, an expert in the field, strongly supports legalization",
            "argumentId": "eacf11ae-779f-4cde-8ab3-9f6d1347d9fb",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994825
        },
        {
            "userId": "e2861103-3cec-4095-a7cf-d8e888f75ed8",
            "argumentText": "Darwinism evolution requires random mutations- so we need to legalize marijuana even if we believe that it'\''s wrong to give it a try",
            "argumentId": "4ad3c9f7-9fe4-4b66-9129-fbeb8f5cefef",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99953926
        },
        {
            "userId": "03f562e4-9b44-4cb8-ade6-e777982770c1",
            "argumentText": "Each individual should decide what he want to use or not as long as he does not harm any other individual",
            "argumentId": "a69e054d-bfc4-4adf-bd6d-37f2c97e51bd",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.7958355
        },
        {
            "userId": "2e79526b-7412-4e58-b20b-8c911d5aaf4b",
            "argumentText": "Easier pain for every body. Speacialy for cancer illness",
            "argumentId": "9c365447-f945-427a-be04-cf25b40fc5b7",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.94930005
        },
        {
            "userId": "9b67a9f8-10c0-4842-a876-ecf64daea033",
            "argumentText": "Even Ben&Jerry'\''s implemented the CBD and TBD in their Ice Cream .",
            "argumentId": "7e2caf6a-cd8a-43b6-97b0-580307181e48",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.980559
        },
        {
            "userId": "4108bdb1-620e-4288-bf28-cfd500798bc2",
            "argumentText": "Even if legalizing Cannabis will make some people addicted to cannabis, most people will use it wisely and cannabis won'\''t have a bad effect on their life.",
            "argumentId": "17bbb209-c012-475d-9480-b537cf88acfd",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99927664
        },
        {
            "userId": "5ded95bd-6a63-4d59-ab7b-839c6fdb6191",
            "argumentText": "Even if some people rationally decide to consumer cannabis, many people will make the decision with limited information or under pressure. The government has a duty to protect these people.",
            "argumentId": "af3e1b09-bb75-4791-abc6-5ef9b1f43465",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.974936
        },
        {
            "userId": "8e627a83-47f2-42ec-aedd-7d7397a710d3",
            "argumentText": "Even if there are risks in consuming cannabis, the state should allow each citizen the freedom to decide for themselves whether or not to use it.",
            "argumentId": "8210aa6d-ff52-469b-8f2a-e1f76c5abee5",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9983113
        },
        {
            "userId": "8e627a83-47f2-42ec-aedd-7d7397a710d3",
            "argumentText": "Even with regulation, legalizing cannabis would provide underage kids with easy access to cannabis.",
            "argumentId": "9b73592f-38a0-44e3-9f6e-03a5a5f26ea3",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.87895143
        },
        {
            "userId": "b975cd84-bf0c-4a41-88ab-8e98c3139525",
            "argumentText": "Every drug is bad. It alters one'\''s behavior and mind uncontrollably, thus putting them and their surrounding at risk. Other substances like alcohol are just harder to criminalize, we should also criminalize them if possible.",
            "argumentId": "6ee41978-2ad4-48bf-a36c-a23e81b3ede2",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.9911461
        },
        {
            "userId": "cf58f6e9-77d9-40ea-848e-597a57274149",
            "argumentText": "Everyone already use it, making it legal will decrease crime",
            "argumentId": "7acda919-260d-43d5-a30f-e00081caee2f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99959815
        },
        {
            "userId": "da130fba-772c-4330-a5dd-afe5cf21b5a3",
            "argumentText": "Financial growth vector for a new industry that is booming where it was legalize6, look up Colorado ",
            "argumentId": "012b8ca6-0c94-49e1-9f7b-e12859607e04",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9836843
        },
        {
            "userId": "2d111a3c-447d-4b03-a09a-bce600299ef2",
            "argumentText": "For kids the borders shall be clear. When the drug is allowed we have to build new messages for our kids.  This is a pre-condition ",
            "argumentId": "7f8034f8-5f64-471a-94dd-b98f3ffe3457",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.985284
        },
        {
            "userId": "5c1555f9-f89e-4363-b1c9-a54c621062e4",
            "argumentText": "Free world gives us the quite moments to do more effective things. Researches show that in the places we have limits, people looking for the way to change the restrictions. ",
            "argumentId": "cd639a2c-edb1-435b-9175-c8bef7006918",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.98689973
        },
        {
            "userId": "5f6ab28f-7e4d-4b63-85eb-5e26d67ea1d1",
            "argumentText": "Freedom of choice is a major principle, and since cannabis use does no harm to the person using it or her surroundings, it should be legalized.",
            "argumentId": "1fdff361-8dad-45aa-8dca-6aed9e39f0de",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99961555
        },
        {
            "userId": "e46557e2-1de2-4af5-830e-4ce95edcd1c4",
            "argumentText": "Giving legalization to canabis can lower or full stop funding of terror organizations and make the world better and safer place",
            "argumentId": "21feb86a-ed84-4b5b-b2aa-39ca95840166",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99941266
        },
        {
            "userId": "2c3990ec-b115-44d9-9044-4bef51964aea",
            "argumentText": "Government has no right to ban the use of relatively harmless subatance.",
            "argumentId": "993d2e1a-9600-47ee-b33e-8864f0294137",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9976679
        },
        {
            "userId": "2293fced-d750-4ffa-874d-cf6254d0e2f4",
            "argumentText": "Government should not decide about action people perform in their private ",
            "argumentId": "bc78e5b0-66c0-47b7-bf71-74d61c1ee731",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9822185
        },
        {
            "userId": "62922e3e-f6a8-4a04-8426-2ffa554c024d",
            "argumentText": "Growing  plant for the medical need invent technologies to increase the plants camestry properties. This  give oppertunities for new industries and a boost for the economy",
            "argumentId": "09d3f619-a57e-417b-bebd-3663438d031c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99781966
        },
        {
            "userId": "aad5b484-3809-4f7d-9844-72f837938c0f",
            "argumentText": "Grown up peolple should have the option to decide for themselves if they want to use cannabis or not",
            "argumentId": "03751299-bb57-4274-8fed-8eaf3406b3ac",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9884007
        },
        {
            "userId": "5bc4e2dd-e7a4-4b80-8f97-c1cd5ef2bbf4",
            "argumentText": "Health and safety: It'\''s better that cannabis would be legal and supervised rather than illegal and mixed with harmful supplements ",
            "argumentId": "c126749a-baa7-4963-a3cc-fe3ebc4d1f48",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994322
        },
        {
            "userId": "5d8bb43f-1452-469b-aee1-72aa85e82d36",
            "argumentText": "Helps sick people to reduce pain and improves it'\''s own life",
            "argumentId": "08716d3d-c000-49d7-be3e-4e63adaccd9f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9990587
        },
        {
            "userId": "e5242a73-f1cd-4d62-a76e-5abd60536cb5",
            "argumentText": "How can you make weed legal if it'\''s make people do nothing? We should make it legal only if we want a society the sit on the sofa all day",
            "argumentId": "12dfdc90-10ca-4c89-b281-41f6286b4da7",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.75118685
        },
        {
            "userId": "5d5f8554-c6ab-4d2d-9061-2288f6507ec5",
            "argumentText": "I believe that legalizing Cannabis is the next challenge for regulators and it'\''s must be done. The cannabis market is one of the fastest growing markets and we can not ignore it. ",
            "argumentId": "d178d186-33ac-4046-a137-dc4751d22da8",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9971272
        },
        {
            "userId": "a02da701-eca4-4634-9079-cbe5b7091b89",
            "argumentText": "I belive it should be  legal and under control. It will reduce the crine  involvment .",
            "argumentId": "18a0ac5a-1bea-46dc-a8c5-aa6f383bba6b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9991406
        },
        {
            "userId": "300bfa90-b6e0-482c-a5aa-d33f0d7f62a8",
            "argumentText": "I have the freedom of coice to kill myself in any way I want.",
            "argumentId": "b1513090-791e-48be-b3b0-f8ea7336e858",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99666965
        },
        {
            "userId": "39fcbc70-9352-4bef-abbe-04d7f56b3dbc",
            "argumentText": "I it will make life easier with the future government of Bibi",
            "argumentId": "93be7ff2-d4a2-4343-a165-450c40b0dc8b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9927219
        },
        {
            "userId": "d494aab0-5731-410e-9aec-c8bb1e93c0ab",
            "argumentText": "I support any effort that grants the citizens the control and the ability to improve their quality of life with enhanced experience.",
            "argumentId": "c26f91c1-e2fd-4391-8715-79a79ed182be",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99895227
        },
        {
            "userId": "a8417ffe-4935-4974-94ac-589dd3f7e75f",
            "argumentText": "I suppott legalization for cannabis mainly because it helps people who needs it mainly for medical and mental reason and this is supported by the academy. ",
            "argumentId": "c612b7a8-046e-4df2-b028-bb44be3be7f7",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9991497
        },
        {
            "userId": "89560e2e-d6b1-46c0-8d23-761884492e18",
            "argumentText": "I think We should give it to I'\''ll people ",
            "argumentId": "e897fdd8-3832-4b2f-8608-5fce09eff2cc",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99934745
        },
        {
            "userId": "dafcc6fc-7d80-4dd3-bbcb-9e6530fa6937",
            "argumentText": "I think it should be allowed since alcohol is much more dangerous ",
            "argumentId": "8fb97d28-0555-4d2e-a897-80cb40a6dc48",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9994165
        },
        {
            "userId": "628065f8-8622-4981-a667-9dadd1dc4ace",
            "argumentText": "I think that the usage of cannabis should be legal. There are a lot of advantages for that. Most of the body'\''s disorders, deseases and pains can be healed and solved by cannabis.",
            "argumentId": "63553515-b7b4-4c1c-9dd6-fafc61da3122",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99950755
        },
        {
            "userId": "d80be019-6f2c-43cd-b1d3-f2ba43a04a6d",
            "argumentText": "I'\''m in for medical purposes only, to help those who suffer, to have a better life",
            "argumentId": "cd372b9b-b454-4923-aa20-0e82addd3ef3",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.95398426
        },
        {
            "userId": "ba39af48-6b0f-4685-8cc7-c36ad5a727a2",
            "argumentText": "I'\''m pro it because it will make the economy thrive ",
            "argumentId": "2ccac3eb-558b-48a6-9fd1-d233f470b8e9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99831796
        },
        {
            "userId": "ba39af48-6b0f-4685-8cc7-c36ad5a727a2",
            "argumentText": "I'\''m pro legalization, as it will reduce the illegal trade of drugs and will make people happier :) ",
            "argumentId": "db35cb77-27ef-4d3c-8972-85ae5613257d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99948275
        },
        {
            "userId": "69505748-419f-442d-9d5c-1f6b470fdfed",
            "argumentText": "If Daneil Melka can, so can I! 1",
            "argumentId": "8f4871f5-aa16-4725-b231-082984f049d5",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.98554265
        },
        {
            "userId": "e5242a73-f1cd-4d62-a76e-5abd60536cb5",
            "argumentText": "If cannabis is illegal just because it'\''s fun. Maybe we should make luna parks.. roller coster and candies illegal as well",
            "argumentId": "5b1b5174-7561-4b8f-b5d5-80349a2da634",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9905255
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "If cannabis is illegal, lots of people go to jail and have their life ruined because of small posetion of cannabis.",
            "argumentId": "751e0592-0a3a-42c0-925c-928ec9aeeb9e",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9960909
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "If cannabis is illegal, people are afraid that they will go to jail and therefore less people use this addictive drug.",
            "argumentId": "bd634817-4acb-47e6-aea3-f21ccc417f91",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.9909028
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "If cannabis is illegal, people by it from dealers, that have incentive to sell them hard drugs also. If cannabis is legal, consumers by it from shops run by state. ",
            "argumentId": "0ee508ac-bb34-4d0e-8015-ca9154420d56",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.993459
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "If cannabis is legal, drug cartels will find it harder to survive, making the world safer.",
            "argumentId": "472b934d-6c13-4a8b-8d58-ff2a2005206d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9938072
        },
        {
            "userId": "efcc1875-be56-4554-adcd-1b2970cf5c69",
            "argumentText": "If cannabis is legal, government can regulate the chemical content and minimize the harmful effects.",
            "argumentId": "ced83be9-767e-4039-ae69-86bd1fbd3fba",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9968505
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "If cannabis is legal, more users will consume it.",
            "argumentId": "efbbb397-f84e-40ca-a79f-8e2293da58f2",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.63421965
        },
        {
            "userId": "93f0aa43-74f7-4931-842c-77d8fb4ed6be",
            "argumentText": "If cannabis is legalized, state will benefit from it through taxation",
            "argumentId": "77de8212-3cfb-471d-9627-fd93b04380f9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99874985
        },
        {
            "userId": "ca1f1de3-bc1a-4866-b451-81123b8b140c",
            "argumentText": "If cannabis was legal nothing would prevent people in critical roles from using it and making poor decisions as a result\n ",
            "argumentId": "9578f899-c692-419c-ae99-97710a8caf9a",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.9472288
        },
        {
            "userId": "ca1f1de3-bc1a-4866-b451-81123b8b140c",
            "argumentText": "If cannabis was legal the conflict with the Palestinians would have ended already",
            "argumentId": "573e6d1d-8b16-48d5-8a22-a6488064eca8",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.98422015
        },
        {
            "userId": "efcc1875-be56-4554-adcd-1b2970cf5c69",
            "argumentText": "If cannabis was legal, it is more likely to be substitute for other more harmful drugs because people will have no need to engage with illegal substances.",
            "argumentId": "3988c5de-1bb6-4160-94d3-d7d3d16faccf",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9933764
        },
        {
            "userId": "32eba00e-81ee-4331-a772-04dbd93e34c8",
            "argumentText": "If cannabis was legalized and regulated, millions would be saved annually in government spending on enforcement.",
            "argumentId": "e04ee9c6-37f2-46b5-85ea-a65b8db8bcc9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99935603
        },
        {
            "userId": "1eb7c9f0-0214-4006-8d2b-97a5da2d2f4b",
            "argumentText": "If we don'\''t do it then other people will do it",
            "argumentId": "b8bab1df-8407-4470-a16e-34e3da3f919e",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9806638
        },
        {
            "userId": "efcc1875-be56-4554-adcd-1b2970cf5c69",
            "argumentText": "If we legalize cannabis, medical institutions can do research on other potential medical benefits of cannabis.",
            "argumentId": "79c0d06a-9d28-467e-a276-26330ece39a7",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9981532
        },
        {
            "userId": "de03cded-8e71-4264-b146-ccd449b536c6",
            "argumentText": "If you want to find drugs you will find them. If cannabis is legalized it will at least regulate the use and take it out of the streets",
            "argumentId": "5ed2880c-fb77-4dfd-8cac-e09966d0bfbf",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.89997363
        },
        {
            "userId": "7af6506a-182a-4bac-9919-406bc710a78b",
            "argumentText": "Illegal drugs are not safe to use so it is better that they will be legal and controlled by health experts",
            "argumentId": "dafabe74-3040-4587-b086-2fd37052ba23",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99572027
        },
        {
            "userId": "b09b4c4f-6777-4593-93a2-3afa4f38063d",
            "argumentText": "Improve the life of sick peoples, helps to focus and stay on open mind and new ideas ",
            "argumentId": "9ef1deab-e36e-4913-a47e-5e5fbc80fc1f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9804342
        },
        {
            "userId": "76d7e83e-49e0-4785-bdcd-0c4700e760e5",
            "argumentText": "In countries that have already legalized cannabis, data has not shown an increase in drug use among the population\n",
            "argumentId": "1e949c3a-b00f-4212-b636-256f8ba4caa2",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9983051
        },
        {
            "userId": "88ad4108-8dac-41c3-9efe-6964976cec92",
            "argumentText": "In favoure.\nLegalizing canabis will open new horizons, especially in medical research, finding cure for relevant illnesses and reduce pain.\nWill reduce legal and law inforces aspects.",
            "argumentId": "f450e4be-a7af-4fa8-9453-52f72ff171c9",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9993036
        },
        {
            "userId": "8e627a83-47f2-42ec-aedd-7d7397a710d3",
            "argumentText": "In states where cannabis has been legal for a while now, the smell of cannabis has pervaded the public space.",
            "argumentId": "123fbc61-a9b5-4494-8eae-e57a645b1845",
            "approved": "YES",
            "userPolarity": "CON",
            "systemPolarity": 0.99389064
        },
        {
            "userId": "5f6ab28f-7e4d-4b63-85eb-5e26d67ea1d1",
            "argumentText": "In the future, we will look back at the times when cannabis was illegal like we do now on times when alcohol was banned, as something ridiculous.",
            "argumentId": "729ab56b-1187-42b8-a795-bd29fa898032",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9073924
        },
        {
            "userId": "0f77f108-9962-4685-b7af-d075774913ad",
            "argumentText": "In the very stressfull life, cannabis can make life more relaxed.",
            "argumentId": "dc7bab57-7499-4dda-b19c-a874c134eb66",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9989039
        },
        {
            "userId": "aa1a5113-981a-4d79-a8b6-55ffa21d31d3",
            "argumentText": "It can stop wars!Cannabis make people more happy",
            "argumentId": "dcdd9e77-65ad-4c07-b4ea-bcecae78a4b0",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995688
        },
        {
            "userId": "c68db79d-3876-4b6c-a8d7-3878a17c9ecc",
            "argumentText": "It feels good and people like it and it makes no sense why it was criminalized to begin with aside from financial pressure from chemical and pharmaceuticalcompanies. ",
            "argumentId": "77396ab7-0201-4f72-8ea2-32dfc3f6463a",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9971286
        },
        {
            "userId": "09c67222-3f6e-4299-ad7d-d5f43062aa74",
            "argumentText": "It grows well in Israeli climate and will bring huge profits to farmers growing it",
            "argumentId": "cf5051fc-7da9-411e-b205-87da29d72d9d",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.997344
        },
        {
            "userId": "ef38315c-1505-4760-a733-2f97e3882953",
            "argumentText": "It has less negative impact than alcohol and cigarettes",
            "argumentId": "61f4a15b-e276-42d4-bb46-40d1962ed706",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99832726
        },
        {
            "userId": "6af697a8-715a-4263-9bd5-fb346abac4ae",
            "argumentText": "It help a lot of people to recover from illness\n",
            "argumentId": "638a8776-a16d-40b5-b8e2-e0697a0f0917",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99939823
        },
        {
            "userId": "3b1f2f80-f56f-4121-86cf-c3acb46466b1",
            "argumentText": "It help people suffering  pain be more relief and back to normal life ",
            "argumentId": "83522a82-ae0f-4b6c-8caf-2db2c1be39da",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99936223
        },
        {
            "userId": "7ecbdba9-5266-423a-8475-5a05cfdedb16",
            "argumentText": "It helps people and reduce pain from patients",
            "argumentId": "47822b3e-bc96-40ba-9070-5c3f033ae450",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99943364
        },
        {
            "userId": "71c122d4-9c9e-4e17-b42b-4aa51ef3cf28",
            "argumentText": "It is difficult to start banning harmful items as ciggarets and alchohol so let us at least not legalize new harmful staff as cannabis ",
            "argumentId": "57da5b35-ebf2-46ba-8180-2f28749b200b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9845835
        },
        {
            "userId": "68edbaa1-361c-4159-a63c-c62bfd80a2e4",
            "argumentText": "It is fun to use and bring people together",
            "argumentId": "a6da2df4-f308-4c6c-a6e2-0d21220cd3d6",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99926114
        },
        {
            "userId": "fd9e899f-6023-401d-90fe-8ffec5ac6d84",
            "argumentText": "It is good for mental problems and can create good mood",
            "argumentId": "8446fac2-7b6b-490e-b7c8-e00c521739ff",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.999426
        },
        {
            "userId": "efcc1875-be56-4554-adcd-1b2970cf5c69",
            "argumentText": "It is illegitimate for the government to limit people'\''s choices of consumption based on the harm the substance might cause them, especially because alcohol and nicotine are currently legal.",
            "argumentId": "0309a972-d6cf-4855-b775-8ba65287dd05",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9939883
        },
        {
            "userId": "5ded95bd-6a63-4d59-ab7b-839c6fdb6191",
            "argumentText": "It is immoral to limit the choice of rational individuals to consume cannabis. If you believe that is it better that the benefits of cannabis outweigh the costs to you, you should be able to.",
            "argumentId": "2412faa8-6e8d-42fe-9ebc-513c59f115d2",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9924954
        },
        {
            "userId": "1556f67b-d7ef-40d0-bcbc-5e9b7d0a1050",
            "argumentText": "It is important to check it as help full for needed people",
            "argumentId": "8391d197-42dd-4171-a46b-5616423c75c8",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99831414
        },
        {
            "userId": "35214292-ae02-492e-88c3-354a87bc0a9c",
            "argumentText": "It is imposebale to belive that in short term from dengerues drag  the best thing . It look like a small noisey group is taking us in to dengeres un noun foutre",
            "argumentId": "f29c7bec-025f-43a8-a213-1f1b28fbfd79",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.51016164
        },
        {
            "userId": "a8a8731b-49f6-46f0-85a7-79fe0e834441",
            "argumentText": "It is in the interest of society to legalize Cannabis. It is illegal only due to financial interests of some strong players in the market.",
            "argumentId": "af5fd29c-5783-4d16-93a0-bfa9d08f742c",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.93698204
        },
        {
            "userId": "c2fd776d-6e4a-49fa-adf8-9a9b5c87b15b",
            "argumentText": "It is inevitable that other countries will legalize it so we might as well be a leader and not a lagger",
            "argumentId": "bf2a7964-1491-4082-bf22-e6d77d082e2b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99104095
        },
        {
            "userId": "a1038de4-70a6-4a8d-a63e-64b6047aed66",
            "argumentText": "It is not possible to fight the demand. It is not harmful.",
            "argumentId": "8ebde303-125e-4057-a5aa-6010ccfc9ef4",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.93612385
        },
        {
            "userId": "53e12cb1-4769-4882-bacb-e765ee0451a7",
            "argumentText": "It make sense because you cannot stop it any way. Too much energy is spent on enforcement that could be spent otherwise. ",
            "argumentId": "0c81620c-6a88-4551-88e8-2abdbabaa3ca",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.97845674
        },
        {
            "userId": "7090ad0e-45de-46a6-9072-43f8b7031f45",
            "argumentText": "It makes people feel good. The American experience with liquor in the period of Prohibition should be a guideline for cannabis a well",
            "argumentId": "f94affc9-012b-4487-8a5a-13179476e840",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9969976
        },
        {
            "userId": "aa1a5113-981a-4d79-a8b6-55ffa21d31d3",
            "argumentText": "It makes people happy.The world have so much sadness and need more happy people",
            "argumentId": "c6a57f15-1c16-4927-91af-4a4ba61a5228",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99916875
        },
        {
            "userId": "f2f9d5cd-a653-4d9c-8067-bf57c21ca59a",
            "argumentText": "It makes sense to use cannabis to relieve pain that standard medications do not help\nBut opposes that any patient who has some pain will be given permission to use",
            "argumentId": "aaffb48b-d581-46e0-8d84-e4f1b1012173",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99697757
        },
        {
            "userId": "c28dc19c-0a8c-41dc-964f-b316bfd78396",
            "argumentText": "It reduces stress and makes you a better person",
            "argumentId": "6f44ca4f-8016-412c-aee9-5549a0b8d297",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99939966
        },
        {
            "userId": "2a1db902-d480-4730-9cca-adb072b72284",
            "argumentText": "It should be easy to create rick simpson oil",
            "argumentId": "a152de77-94e4-4c4a-ade0-8b07e6f0a0a6",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9678191
        },
        {
            "userId": "e4d80154-db87-4f63-b3d7-1905681dc2cd",
            "argumentText": "It should be legalised because it is healthy, and fun too",
            "argumentId": "28617409-a4db-4c19-9edd-9ece8666a7a4",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9996053
        },
        {
            "userId": "e4d80154-db87-4f63-b3d7-1905681dc2cd",
            "argumentText": "It should be legalised because then many normative people will not become criminals",
            "argumentId": "d0884ef1-f40b-4228-8fc5-abede03a98ae",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995853
        },
        {
            "userId": "50b2790a-24b1-4e9b-a2c4-bf4dfb06da49",
            "argumentText": "It was proven as non harmful and addictive drug",
            "argumentId": "c1cefdef-43b9-4b4c-bfed-98c65c67f480",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9974048
        },
        {
            "userId": "681f114a-1d31-4db2-a3a5-234443a75f07",
            "argumentText": "It will be much easier to purchase high quality products, and will cut off terrorist groups funds and power. It will eliminate pain for incurable diseases patients. People will be calmer and it will be fun!",
            "argumentId": "525fcc73-0b52-4dcc-86a4-b9e17f9df2e4",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99939346
        },
        {
            "userId": "50b2790a-24b1-4e9b-a2c4-bf4dfb06da49",
            "argumentText": "It will contribute to legal issues concerning research and new breeds development. ",
            "argumentId": "b0e41f27-2735-4530-89dc-bd683f71cb0e",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.97302926
        },
        {
            "userId": "1eb7c9f0-0214-4006-8d2b-97a5da2d2f4b",
            "argumentText": "It will create lots of new business places. Every one will be able to grow it and consume",
            "argumentId": "8f4a7649-a962-4a63-9ab6-f667a4a9b489",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99895895
        },
        {
            "userId": "2a1db902-d480-4730-9cca-adb072b72284",
            "argumentText": "It will ease the pain for people with painful disis",
            "argumentId": "ecae6bad-861f-4c23-aa34-1a4a5c0d24cb",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99944246
        },
        {
            "userId": "de03cded-8e71-4264-b146-ccd449b536c6",
            "argumentText": "It will help menu people with chronic pain and illnesses deal with the pain and lead a normal and full life",
            "argumentId": "adf8a49b-9a42-47e7-a307-4cfa7db6b0dc",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99931836
        },
        {
            "userId": "e46557e2-1de2-4af5-830e-4ce95edcd1c4",
            "argumentText": "It will make a btter world for all pf us",
            "argumentId": "25b0e572-ae41-4304-90e4-36fb7b12ab2f",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9937115
        },
        {
            "userId": "e1e647e2-2eaf-47f2-a476-f0c366127041",
            "argumentText": "It will make cannabis more avilable for leople who need it cor medica use",
            "argumentId": "577f363a-7653-440e-bfec-ba298aaf60c8",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9882393
        },
        {
            "userId": "ba498d72-65e2-4bec-92c6-40c9f2a42666",
            "argumentText": "It will prevent criminals elements and will improve the quelaty of life.",
            "argumentId": "a85585ee-7747-42c9-bec5-11585ed603f6",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99935937
        },
        {
            "userId": "42f4089d-d14b-4edd-8d25-ae80f41b4d96",
            "argumentText": "It will save money for government and creates new jobs ",
            "argumentId": "2c0de79b-fabe-4c07-a37e-71d89d7fb2a0",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9992416
        },
        {
            "userId": "c68db79d-3876-4b6c-a8d7-3878a17c9ecc",
            "argumentText": "It'\''s a nice post coital relaxation. After sex you just want to light one up and reflect. ",
            "argumentId": "17276b3b-f6e8-456e-864a-079e5101cca1",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9976405
        },
        {
            "userId": "bf4dc2c8-cf2a-4801-90f1-5226ede29926",
            "argumentText": "It'\''s freedom of nature and citizen'\''s against country ",
            "argumentId": "52106946-d5be-410b-b920-ccf2d5c17998",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9985291
        },
        {
            "userId": "2293fced-d750-4ffa-874d-cf6254d0e2f4",
            "argumentText": "It'\''s fun! And it should be legalized for all",
            "argumentId": "ea0a2b3a-672d-4e42-856a-6d3b068ac7c8",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9995903
        },
        {
            "userId": "5bfa4ddf-ee99-4f5c-961a-de8c2f0b4614",
            "argumentText": "It'\''s give you possibility  to dream and to create, to brake thru the borders",
            "argumentId": "9067a706-6458-4274-8b37-95e24d98da48",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99603224
        },
        {
            "userId": "0e146de7-1add-463d-a1ee-b9a6ccb4d01d",
            "argumentText": "It'\''s good for you and will make you happy",
            "argumentId": "60abfc4a-e073-4265-96d0-66f5f5e65177",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.99949133
        },
        {
            "userId": "1eb7c9f0-0214-4006-8d2b-97a5da2d2f4b",
            "argumentText": "It'\''s made from nature with love. Let'\''s go for it ",
            "argumentId": "aefe78b4-222b-4310-a07a-fa58ebdda54b",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.5823128
        },
        {
            "userId": "be305521-1b9b-46d8-ad45-ba0355ddd25a",
            "argumentText": "It'\''s make  life more enjoyable  and relaxing with no anger \n",
            "argumentId": "127031a7-62bf-4451-b34e-235848835ae1",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.998476
        },
        {
            "userId": "fcf9835d-15d9-40ed-8809-77e2277dc346",
            "argumentText": "taking responsibility and choose the life we want. This is a fundemental message to next generation allowing comfort to those who feel pain and may have some comfort and create options to various pepole & needs.",
            "argumentId": "637a386a-4e73-40f8-b98a-268098ac04af",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9829985
        },
        {
            "userId": "82fa7df5-3ebc-4ffd-9726-e6a40f734c5b",
            "argumentText": "there will be more fun in being ill",
            "argumentId": "9e8e91f8-8341-47e0-acbb-7f693f428452",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9449179
        },
        {
            "userId": "e5242a73-f1cd-4d62-a76e-5abd60536cb5",
            "argumentText": "when cannabis is not harming any one. How can it be ilegal.. maybe we should make tea iligal to",
            "argumentId": "16a051ab-3a3b-40fa-8c17-d89e17761cfb",
            "approved": "YES",
            "userPolarity": "PRO",
            "systemPolarity": 0.9982282
        }
    ]